#
# spec file for package python-pipdeptree
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pipdeptree
Version:        2.13.2
Release:        1.2
Summary:        Command line utility to show dependency tree of packages
License:        MIT
URL:            https://github.com/naiquevin/pipdeptree
Source:         https://github.com/naiquevin/pipdeptree/archive/%{version}.tar.gz#/pipdeptree-%{version}.tar.gz
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pip
Suggests:       python-graphviz
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module graphviz}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module virtualenv}
BuildRequires:  graphviz-gnome
# /SECTION
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
Command line utility to show dependency tree of packages.

%prep
%setup -q -n pipdeptree-%{version}

%build
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pipdeptree

%check
%pytest -k 'not test_custom_interpreter and not test_console'

%post
%{python_install_alternative pipdeptree}

%postun
%{python_uninstall_alternative pipdeptree}

%files %{python_files}
%doc CHANGES.md README.md
%license LICENSE
%python_alternative %{_bindir}/pipdeptree
%{python_sitelib}/pipdeptree
%{python_sitelib}/pipdeptree-%{version}*-info

%changelog
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 2.13.2:
  * models/package: have `version_spec` only exist in
    `ReqPackage`
  * Use "Any" value if necessary for required version in JSON
    render
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.13.1:
  * models/package: move `requires()` and `version` to
    `DistPackage`
  * Update README to show 2.13.0 CLI syntax
- update to 2.13.0:
  * Add missing `user_only` field in `Options`
  * Exit with error when `-p` given patterns that fail to match
- update to 2.12.0:
  * Detect dependency cycles beyond a depth = 2
- update to 2.11.0:
  * Have --packages and --all work together
- update to 2.10.2:
  * Internal refactors.
- update to 2.10.1:
  * Fix graphviz CLI failing
- update to 2.10.0:
  * Split project to parts
  * Drop 3.7 support
  * Fix entrypoints
  * Improve CLI
  * Add type check to CI and fix errors
  * Simplify loops
- update to 2.9.6:
  * Avoid changing `t` in `randomized_dag_copy()` by shallow
    copying
- update to 2.9.5:
  * Exclude dependabot and pre-commit ci from release notes
  * Add type information
- update to 2.9.4:
  * Allow to force encoding
  * Implement -d/--depth argument
* Thu May  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.7.1:
  * Bump pypa/gh-action-pypi-publish from 1.8.3 to 1.8.5 by
    @dependabot in #219
  * Bump deps and tools by @gaborbernat in #220
  * Bump deps and tools by @gaborbernat in #222
  * Bump deps and tools by @gaborbernat in #224
  * Add trusted-publish by @gaborbernat in #226
  * Fix typo: "Maermaid" by @gschaffner in #227
  * Add 3.12 support by @gaborbernat in #228
- 2.7.0:
  * Bump deps and tools by @gaborbernat in #210
  * Bump deps and tools by @gaborbernat in #212
  * Bump pypa/gh-action-pypi-publish from 1.8.1 to 1.8.3 by
    @dependabot in #214
  * Implement: Use fnmatch for include and exclude #213 by @jensens in
    [#215]
- 2.6.0:
  * Bump deps and tools by @gaborbernat in #203
  * Bump pypa/gh-action-pypi-publish from 1.6.4 to 1.8.1 by
    @dependabot in #206
  * Handle and test mermaid output for a reversed tree by @ajkerrigan
    in #209
- 2.5.2:
  * Quote Mermaid node and edge labels by @kdeldycke in #200
  * Unique IDs in Mermaid not conflicting with reserved keywords by
    @kdeldycke in #201
- 2.5.1:
  * Fix mermaid option by @kdeldycke in #196
  * Bump tools and deps and fix changelog by @gaborbernat in #199
- Update to 2.5.0:
  * Implements Mermaid output by @kdeldycke in #195
- 2.4.0:
  * Bump pypa/gh-action-pypi-publish from 1.5.1 to 1.5.2 by
    @dependabot in #182
  * Bump pypa/gh-action-pypi-publish from 1.5.2 to 1.6.4 by
    @dependabot in #185
  * Bump deps and tools by @gaborbernat in #192
  * Make the output of the dot format deterministic and stable by
    @kdeldycke in #189
- 2.3.3:
  * [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #176
  * Update README for tested Python versions by @tomkins in #178
- 2.3.2:
  * Generalize license by @gaborbernat in #179
- 2.3.1:
  * Use importlib.metadata for guess_version instead of importing the
    module by @saaketp in #171
- 2.3.0:
  * Make pipdeptree works with python 3.11 by @dqkqd in #173
* Fri Jan 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.1:
  * Fix --user-only and --freeze flags which were broken after the last release.
  * Fix for compatibility with new version of graphviz (>= 0.18.1).
  * Fix pipdeptree to work with pip version 21.3. The _internal pip api that was being used earlier is now replaced with new functions. (PR #154)
  * JSON output is sorted alphabetically to make it deterministic
  * Fix --freeze option due to breaking changes in pip's internal api in version > 21.1.1
  * Include license file in dist package
  * Support for running in the context of a virtualenv (without installing pipdeptree inside the virtualenv)
  * Avoid crash when rendering cyclic dependencies
  * Fix graphviz (dot file) output
  * Handle a (rare) case while guessing version of a package
  * Improve integration tests
- Remove the hacked together virtualenv that was 2.7 based, since it is no
  longer needed.
- Add virtualenv to BuildRequires.
* Wed Aug 19 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0.0
  * Use pkg_resources vendored with pip
* Thu Mar  7 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.13.2
